/*
 * This file is generated by objective.metadata
 *
 * Last update: Sun Aug 10 20:41:47 2014
 */

static void __attribute__((__used__)) use_protocols(void)
{
    PyObject* p __attribute__((__unused__));
#if PyObjC_BUILD_RELEASE >= 1010
    p = PyObjC_IdToPython(@protocol(AVCaptureViewDelegate));
    Py_XDECREF(p);
#endif
#if PyObjC_BUILD_RELEASE >= 1015
    p = PyObjC_IdToPython(@protocol(AVPictureInPictureControllerDelegate));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(AVPlayerViewPictureInPictureDelegate));
    Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(AVRoutePickerViewDelegate));
    Py_XDECREF(p);
#endif
}
